Public Class FileHandler

    '
    ' File handling in TX Text Control Words
    '
    ' The sample program works in 2 modes, Default and XML mode. XML mode is entered when 
    ' an  XML file is loaded. An XML file can only be saved as XML, but can be exported to 
    ' all other formats.
    '
    ' These file types will be available in the Save and Export dialog boxes. Save types are
    ' are read/write, whereas Export types are those which cannot be loaded back in. When
    ' a file is exported, the original file name and type are preserved.
    '
    Const DefaultExportTypes = TXTextControl.StreamType.AdobePDF + TXTextControl.StreamType.CascadingStylesheet
    Const DefaultSaveTypes = TXTextControl.StreamType.All - DefaultExportTypes - TXTextControl.StreamType.XMLFormat
    Const DefaultInsertTypes = TXTextControl.StreamType.All - DefaultExportTypes - TXTextControl.StreamType.XMLFormat
    Const XMLModeSaveTypes = TXTextControl.StreamType.XMLFormat
    Const XMLModeExportTypes = TXTextControl.StreamType.All - XMLModeSaveTypes
    Const XMLModeInsertTypes = TXTextControl.StreamType.PlainAnsiText + TXTextControl.StreamType.PlainText

    Private m_DocumentFileName As String = ""
    Private m_DocumentStreamType As TXTextControl.StreamType
    Private m_TextControl As TXTextControl.TextControl
    Private m_DocumentDirty As Boolean

    ' CSS related options
    Private m_CSSFileName As String = ""
    Private m_CSSSaveMode As TXTextControl.CssSaveMode

    ' PDF related options
    Private m_PDFMasterPassword As String = ""
    Private m_PDFUserPassword As String = ""
    Private m_PDFDocumentAccessPermissions As TXTextControl.DocumentAccessPermissions = _
            TXTextControl.DocumentAccessPermissions.AllowAll

    Public WriteOnly Property TextControl() As TXTextControl.TextControl
        Set(ByVal TextControl As TXTextControl.TextControl)
            m_TextControl = TextControl
        End Set
    End Property

    Public Property DocumentFileName() As String
        Set(ByVal FileName As String)
            m_DocumentFileName = FileName
        End Set
        Get
            Return m_DocumentFileName
        End Get
    End Property

    Public ReadOnly Property InXMLMode() As Boolean
        Get
            Return (m_DocumentStreamType = TXTextControl.StreamType.XMLFormat)
        End Get
    End Property

    Public Property DocumentDirty() As Boolean
        Get
            Return m_DocumentDirty
        End Get
        Set(ByVal Dirty As Boolean)
            m_DocumentDirty = Dirty
        End Set
    End Property

    Public Property CSSFileName() As String
        Get
            Return m_CSSFileName
        End Get
        Set(ByVal Value As String)
            m_CSSFileName = Value
        End Set
    End Property

    Public Property CSSSaveMode() As TXTextControl.CssSaveMode
        Get
            Return m_CSSSaveMode
        End Get
        Set(ByVal Value As TXTextControl.CssSaveMode)
            m_CSSSaveMode = Value
        End Set
    End Property

    Public Property PDFMasterPassword() As String
        Set(ByVal Value As String)
            m_PDFMasterPassword = value
        End Set
        Get
            Return m_PDFMasterPassword
        End Get
    End Property

    Public Property PDFUserPassword() As String
        Set(ByVal Value As String)
            m_PDFUserPassword = value
        End Set
        Get
            Return m_PDFUserPassword
        End Get
    End Property

    Public Property PDFDocumentAccessPermissions() As TXTextControl.DocumentAccessPermissions
        Set(ByVal Value As TXTextControl.DocumentAccessPermissions)
            m_PDFDocumentAccessPermissions = Value
        End Set
        Get
            Return m_PDFDocumentAccessPermissions
        End Get
    End Property

    Public Sub FileOpen()
        Dim LoadSettings As New TXTextControl.LoadSettings

        If m_DocumentFileName = "" Then
            m_TextControl.Load(TXTextControl.StreamType.All, LoadSettings)
        Else
            If m_DocumentFileName.ToLower().EndsWith(".rtf") Then
                m_TextControl.Load(m_DocumentFileName, TXTextControl.StreamType.RichTextFormat, LoadSettings)
            ElseIf m_DocumentFileName.ToLower().EndsWith(".doc") Then
                m_TextControl.Load(m_DocumentFileName, TXTextControl.StreamType.MSWord, LoadSettings)
            ElseIf m_DocumentFileName.ToLower().EndsWith(".txt") Then
                m_TextControl.Load(m_DocumentFileName, TXTextControl.StreamType.PlainText, LoadSettings)
            ElseIf m_DocumentFileName.ToLower().EndsWith(".htm") Or m_DocumentFileName.EndsWith(".html") Then
                m_TextControl.Load(m_DocumentFileName, TXTextControl.StreamType.HTMLFormat, LoadSettings)
            End If
        End If

        If LoadSettings.LoadedFile <> "" Then
            m_DocumentFileName = LoadSettings.LoadedFile
            m_DocumentStreamType = LoadSettings.LoadedStreamType
            m_DocumentDirty = False
            m_TextControl.PageMargins = LoadSettings.PageMargins
            m_TextControl.PageSize = LoadSettings.PageSize
            m_CSSFileName = LoadSettings.CssFileName
            m_CSSSaveMode = TXTextControl.CssSaveMode.None
        End If
    End Sub

    Public Sub FileSave()
        Dim SaveSettings As New TXTextControl.SaveSettings

        SaveSettings.PageMargins = m_TextControl.PageMargins
        SaveSettings.PageSize = m_TextControl.PageSize
        SaveSettings.CssFileName = m_CSSFileName
        SaveSettings.CssSaveMode = m_CSSSaveMode

        If DocumentFileName <> "" Then
            ' save under same name and type
            m_TextControl.Save(DocumentFileName, m_DocumentStreamType, SaveSettings)
        Else
            ' save as..
            If InXMLMode Then
                m_TextControl.Save(XMLModeSaveTypes, SaveSettings)
            Else
                m_TextControl.Save(DefaultSaveTypes, SaveSettings)
            End If
        End If
        If SaveSettings.SavedFile <> "" Then
            m_DocumentFileName = SaveSettings.SavedFile
            m_DocumentStreamType = SaveSettings.SavedStreamType
            m_DocumentDirty = False
        End If
    End Sub

    Public Sub FileSaveAs()
        Dim SaveSettings As New TXTextControl.SaveSettings

        SaveSettings.PageMargins = m_TextControl.PageMargins
        SaveSettings.PageSize = m_TextControl.PageSize
        SaveSettings.CssFileName = m_CSSFileName
        SaveSettings.CssSaveMode = m_CSSSaveMode

        If InXMLMode Then
            m_TextControl.Save(XMLModeSaveTypes, SaveSettings)
        Else
            m_TextControl.Save(DefaultSaveTypes, SaveSettings)
        End If

        If SaveSettings.SavedFile <> "" Then
            If m_DocumentStreamType <> SaveSettings.SavedStreamType Then
                ' reload file if saved in a different format
                m_TextControl.ResetContents()
                m_TextControl.Load(SaveSettings.SavedFile, SaveSettings.SavedStreamType)
            End If
            m_DocumentFileName = SaveSettings.SavedFile
            m_DocumentStreamType = SaveSettings.SavedStreamType
            m_DocumentDirty = False
        End If
    End Sub

    Public Sub Export()
        Dim SaveSettings As New TXTextControl.SaveSettings

        SaveSettings.UserPassword = m_PDFUserPassword
        SaveSettings.MasterPassword = m_PDFMasterPassword
        SaveSettings.DocumentAccessPermissions = m_PDFDocumentAccessPermissions

        If InXMLMode() Then
            m_TextControl.Save(XMLModeExportTypes, SaveSettings)
        Else
            m_TextControl.Save(DefaultExportTypes, SaveSettings)
        End If
    End Sub

    Public Sub Insert()
        Dim LoadSettings As New TXTextControl.LoadSettings

        If InXMLMode Then
            m_TextControl.Selection.Load(XMLModeInsertTypes, LoadSettings)
        Else
            m_TextControl.Selection.Load(DefaultInsertTypes, LoadSettings)
        End If

        If LoadSettings.LoadedFile <> "" Then
            m_DocumentDirty = True
        End If
    End Sub

End Class
